require './test/test_helper'

class BrainspaceCollectionTest < Minitest::Test

  def setup
    Brainspace.config.user = 'dummy@dummy.com'
    Brainspace.config.password = 'DUMMY'

    VCR.use_cassette('auth') do
      Brainspace.apikey
    end

  end

  def test_exists
    assert Brainspace::Collection
  end

  def test_it_gives_back_a_single_collection
    VCR.use_cassette('bitcoin_colleciton') do
      collection = Brainspace::Collection.find(3713)
      assert_equal Brainspace::Collection, collection.class

      # Check that the fields are accessible by our model
      assert_equal "3713", collection.id
      assert_equal "100084", collection.user_id
      assert_equal "Bitcoin", collection.name
      assert_equal "http://www.bitcoincasino.org/wp-content/uploads/2013/07/bitcoin1.jpg", collection.image
      assert_equal "", collection.description
      assert collection.meta_data
      assert_equal "#00A7FF", collection.meta_data.color
      assert_equal 5, collection.item_count

    end
  end

  def test_it_returns_all_collections
    VCR.use_cassette('all_collections') do
      result = Brainspace::Collection.all

      # Make sure we got all the cars
      assert_equal 11, result.length

      # Make sure that the JSON was parsed
      assert result.kind_of?(Array)
      assert result.first.kind_of?(Brainspace::Collection)
    end
  end

  def test_it_discovers_articles
    VCR.use_cassette('discovery') do
      result = Brainspace::Collection.discovery(3713)

      assert_equal 18, result.length

      assert result.kind_of?(Array)
      assert result.first.kind_of?(Brainspace::Article)
    end
  end
end
